"""Default workflow."""

__author__ = "Lukas Leufen"
__date__ = '2020-06-26'

import inspect
from mlair.helpers import remove_items
from mlair.run_modules import ExperimentSetup, PreProcessing, PartitionCheck, ModelSetup, Training, PostProcessing
from mlair.workflows.abstract_workflow import Workflow


class DefaultWorkflow(Workflow):
    """A default workflow executing ExperimentSetup, PreProcessing, ModelSetup, Training and PostProcessing in exact
    the mentioned ordering."""

    def __init__(self, stations=None,
                 train_model=None, create_new_model=None,
                 window_history_size=None,
                 experiment_date="testrun",
                 variables=None, statistics_per_var=None,
                 start=None, end=None,
                 target_var=None, target_dim=None,
                 window_lead_time=None,
                 dimensions=None,
                 interpolation_method=None, time_dim=None, limit_nan_fill=None,
                 train_start=None, train_end=None, val_start=None, val_end=None, test_start=None, test_end=None,
                 use_all_stations_on_all_data_sets=None, fraction_of_train=None,
                 experiment_path=None, plot_path=None, forecast_path=None, bootstrap_path=None,
                 overwrite_local_data=None,
                 sampling=None,
                 permute_data_on_training=None, extreme_values=None, extremes_on_right_tail_only=None,
                 transformation=None,
                 train_min_length=None, val_min_length=None, test_min_length=None,
                 plot_list=None,
                 model=None,
                 batch_size=None,
                 epochs=None,
                 data_handler=None,
                 **kwargs):
        super().__init__()

        # extract all given kwargs arguments
        params = remove_items(inspect.getfullargspec(self.__init__).args, "self")
        kwargs_default = {k: v for k, v in locals().items() if k in params and v is not None}
        self._setup(**kwargs_default, **kwargs)

    def _setup(self, **kwargs):
        """Set up default workflow."""
        self.add(ExperimentSetup, **kwargs)
        self.add(PreProcessing)
        self.add(ModelSetup)
        self.add(Training)
        self.add(PostProcessing)


class DefaultWorkflowHPC(DefaultWorkflow):
    """A default workflow for Jülich HPC systems executing ExperimentSetup, PreProcessing, PartitionCheck, ModelSetup,
    Training and PostProcessing in exact the mentioned ordering."""

    def _setup(self, **kwargs):
        """Set up default workflow."""
        self.add(ExperimentSetup, **kwargs)
        self.add(PreProcessing)
        self.add(PartitionCheck)
        self.add(ModelSetup)
        self.add(Training)
        self.add(PostProcessing)
