__author__ = "Lukas Leufen"
__date__ = '2020-06-29'

import argparse
from mlair.workflows import DefaultWorkflow
# from mlair.model_modules.recurrent_networks import RNN as chosen_model
from mlair.helpers import remove_items
from mlair.configuration.defaults import DEFAULT_PLOT_LIST
import os
import tensorflow as tf


def load_stations():
    import json
    try:
        filename = 'supplement/station_list_north_german_plain_rural.json'
        with open(filename, 'r') as jfile:
            stations = json.load(jfile)
    except FileNotFoundError:
        stations = None
    return stations


def main(parser_args):
    # tf.compat.v1.disable_v2_behavior()
    plots = remove_items(DEFAULT_PLOT_LIST, ["PlotConditionalQuantiles", "PlotPeriodogram"])
    workflow = DefaultWorkflow(  # stations=load_stations(),
        # stations=["DEBW087","DEBW013", "DEBW107",  "DEBW076"],
        stations=["DEBW013", "DEBW087", "DEBW107", "DEBW076"],
        train_model=False, create_new_model=True, network="UBA",
        evaluate_feature_importance=False,  # plot_list=["PlotCompetitiveSkillScore"],
        competitors=["test_model", "test_model2"],
        competitor_path=os.path.join(os.getcwd(), "data", "comp_test"),
        **parser_args.__dict__, start_script=__file__)
    workflow.run()


if __name__ == "__main__":
    parser = argparse.ArgumentParser()
    parser.add_argument('--experiment_date', metavar='--exp_date', type=str, default="testrun",
                        help="set experiment date as string")
    args = parser.parse_args()
    main(args)
